Index: webkit/plugins/ppapi/ppb_file_chooser_impl.h |
diff --git a/webkit/plugins/ppapi/ppb_file_chooser_impl.h b/webkit/plugins/ppapi/ppb_file_chooser_impl.h |
index d5afc2d74f2f81487be726721d11fa113e2798e0..478e1c5d897bf7ee638e0a215b1560356a38cde2 100644 |
--- a/webkit/plugins/ppapi/ppb_file_chooser_impl.h |
+++ b/webkit/plugins/ppapi/ppb_file_chooser_impl.h |
@@ -36,12 +36,12 @@ class PPB_FileChooser_Impl : public ::ppapi::Resource, |
public: |
PPB_FileChooser_Impl(PP_Instance instance, |
PP_FileChooserMode_Dev mode, |
- const char* accept_mime_types); |
+ const char* accept_types); |
virtual ~PPB_FileChooser_Impl(); |
static PP_Resource Create(PP_Instance instance, |
PP_FileChooserMode_Dev mode, |
- const char* accept_mime_types); |
+ const char* accept_types); |
// Resource overrides. |
virtual PPB_FileChooser_Impl* AsPPB_FileChooser_Impl(); |
@@ -78,15 +78,15 @@ class PPB_FileChooser_Impl : public ::ppapi::Resource, |
PP_Var suggested_file_name, |
const PP_CompletionCallback& callback) OVERRIDE; |
// Splits a comma-separated MIME type list |accept_mime_types|, trims the |
// resultant split types, makes them lowercase, and returns them. |
// Though this should be private, this is public for testing. |
WEBKIT_PLUGINS_EXPORT static std::vector<WebKit::WebString> ParseAcceptValue( |
- const std::string& accept_mime_types); |
+ const std::string& accept_types); |
private: |
PP_FileChooserMode_Dev mode_; |
- std::string accept_mime_types_; |
+ std::string accept_types_; |
scoped_refptr< ::ppapi::TrackedCallback> callback_; |
// When using the v0.6 of the API, this will contain the output for the |
@@ -78,15 +78,15 @@ class PPB_FileChooser_Impl : public ::ppapi::Resource, |
PP_Var suggested_file_name, |
const PP_CompletionCallback& callback) OVERRIDE; |
- // Splits a comma-separated MIME type list |accept_mime_types|, trims the |
+ // Splits a comma-separated MIME type/extension list |accept_types|, trims the |
// resultant split types, makes them lowercase, and returns them. |
// Though this should be private, this is public for testing. |